@@ -29,65 +29,66 @@ summary.glca <- function(
    cat("\nCall:\n",  paste(deparse(object$call), sep = "\n", collapse = "\n"),
        "\n\n", sep = "")
 
-   cat("Manifest items :\n", var.names$y.names, "\n")
+   cat("Manifest items :", var.names$y.names, "\n")
    if (!is.null(object$call$group)) cat("Grouping variable :", object$call$group, "\n")
-   if (model$W > 0L) {
-      if (model$Q > 0L) cat("Covariates (Level 2) : \n", var.names$Z.names, "\n")
-      if (model$P > 1L) cat("Covariates (Level 1) : \n", var.names$X.names, "\n")
-   } else if (model$P > 1L) cat("Covariates : \n", var.names$X.names, "\n")
+   if (model$P > 1L) cat("Covariates (Level 1) :", var.names$X.names, "\n")
+   if (model$Q > 0L) cat("Covariates (Level 2) :", var.names$Z.names, "\n")
 
-   cat("\nModel :", model$type, "\n")
+   cat("\nCategories for manifest items :\n")
+   print(var.names$resp.name)
+
+   cat("\nModel :", model$type, "\n\n")
    if (model$W > 1L){
       cat("Number of latent classes :", model$C, "\n")
       cat("Number of latent clusters :", model$W, "\n")
-      cat("\nMean prevalence for latent clusters:\n")
-      print(round(colMeans(posterior$cluster), 5L))
-      cat("\nMean prevalence for latent classes:\n")
-      print(round(posterior$wclass, 5L))
-      cat("\n")
    } else {
       cat("Number of latent classes :", model$C, "\n")
-      if (model$G < 10L) {
-         cat("\nMean prevalence for latent classes:\n")
-         prev = as.matrix(do.call(rbind, lapply(posterior, colMeans)))
-         dimnames(prev) = list(var.names$g.names,
-                               paste0("Class ", 1L:model$C))
-         print(round(prev, 5L))
-      } else {
-         cat("\nMean prevalence for latent classes:\n")
-         print(round(colMeans(do.call(rbind, posterior)), 5))
-      }
    }
-   cat("\nNumber of parameters :", model$npar, "\n")
    if (model$G > 1)
       cat("Number of groups :", model$G, "\n")
+   cat("Number of observations :", model$N, "\n")
+   cat("Number of parameters :", model$npar, "\n")
 
    cat("\nlog-likelihood :", gof$loglik,
        "\n     G-squared :", gof$Gsq,
        "\n           AIC :", gof$aic,
-       "\n           BIC :", gof$bic)
+       "\n           BIC :", gof$bic, "\n")
 
-   cat("\n\nResponse numbering:\n")
-   print(var.names$resp.name)
+   if (model$W > 1L){
+      cat("\nMarginal prevalences for latent classes :\n")
+      print(round(colMeans(do.call(rbind, posterior$class)), 5L))
+      cat("\nMarginal prevalences for latent clusters :\n")
+      print(round(colMeans(posterior$cluster), 5L))
+      cat("\nClass prevalences by cluster :\n")
+      print(round(posterior$wclass, 5L))
+   } else {
+      cat("\nMarginal prevalences for latent classes :\n")
+      print(round(colMeans(do.call(rbind, posterior)), 5L))
+      if (model$G < 15L) {
+         cat("\nClass prevalences by group :\n")
+         prev = as.matrix(do.call(rbind, lapply(posterior, colMeans)))
+         dimnames(prev) = list(var.names$g.names,
+                               paste0("Class ", 1L:model$C))
+         print(round(prev, 5L))
+         cat("\n")
+      } else {
+         cat("\nToo many groups to be printed.\n")
+      }
+   }
 
-   cat("\nEstimated model parameters :\n")
    if (model$W > 1L) {
-      cat("Delta :\n")
-      print(round(param$delta, digits))
-      cat("\n")
-
       if (model$P > 1L | model$Q > 0L) {
-         cat("Beta (level 1) :\n")
-         print(lapply(param$beta[[1L]], round, digits))
+         cat("\nBeta (level 1) :\n")
+         for (w in 1:model$W) {
+            cat("Cluster", w, "\n")
+            print(round(param$beta[[1L]][[w]], digits))
+            cat("\n")
+         }
          if (model$Q > 0L) {
             cat("Beta (level 2) :\n")
             print(round(param$beta[[2L]], digits))
          }
          cat("\n")
-      } else {
-         cat("Gamma :\n")
-         print(round(param$gamma, digits))
-         cat("\n")
       }
 
       if (all(model$R == 2L)) {
@@ -96,7 +97,7 @@ summary.glca <- function(
             round(param$rho[[m]][,1L], digits))
          colnames(Rhomat) <- var.names$y.names
          print(Rhomat)
-         cat ("Rho (Y = 2) :\n")
+         cat ("\nRho (Y = 2) :\n")
          Rhomat <- sapply(1L:model$M, function(m)
             round(param$rho[[m]][,2L], digits))
          colnames(Rhomat) <- var.names$y.names
@@ -108,33 +109,19 @@ summary.glca <- function(
             print(round(param$rho[[m]], digits))
          }
       }
-
       cat("\n")
    } else {
       if (model$P > 1L) {
          cat("Beta :\n")
          if (model$G > 1L) {
-            if (model$coeff.inv) {
-               cat("Intercepts :\n")
-               int = do.call(rbind, lapply(param$beta, function(x) x[1L,]))
-               rownames(int) = paste0("Group :", var.names$g.names)
-               print(round(int, digits))
-               cat("\nCoefficients :\n")
-               print(round(param$beta[[1L]][2L:model$P,], digits))
-            } else {
-               for (g in 1L:model$G) {
-                  cat("Group :", var.names$g.names[g], "\n")
-                  print(round(param$beta[[g]], digits))
-               }
+            for (g in 1L:model$G) {
+               cat("Group :", var.names$g.names[g], "\n")
+               print(round(param$beta[[g]], digits))
+               cat("\n")
             }
          } else {
             print(round(param$beta[[1L]], digits))
          }
-         cat("\n")
-      } else {
-         cat("Gamma :\n")
-         print(round(param$gamma, digits))
-         cat("\n")
       }
 
       if (model$G == 1L) {
@@ -144,7 +131,7 @@ summary.glca <- function(
                round(param$rho[[1L]][[m]][,1L], digits))
             colnames(Rhomat) <- var.names$y.names
             print(Rhomat)
-            cat ("Rho (Y = 2) :\n")
+            cat ("\nRho (Y = 2) :\n")
             Rhomat <- sapply(1L:model$M, function(m)
                round(param$rho[[1L]][[m]][,2L], digits))
             colnames(Rhomat) <- var.names$y.names
@@ -164,7 +151,7 @@ summary.glca <- function(
                   round(param$rho[[1L]][[m]][,1L], digits))
                colnames(Rhomat) <- var.names$y.names
                print(Rhomat)
-               cat ("Rho (Y = 2) :\n")
+               cat ("\nRho (Y = 2) :\n")
                Rhomat <- sapply(1L:model$M, function(m)
                   round(param$rho[[1L]][[m]][,2L], digits))
                colnames(Rhomat) <- var.names$y.names
@@ -187,7 +174,7 @@ summary.glca <- function(
                   print(Rhomat)
                   cat("\n")
                }
-               cat ("Rho (Y = 2) :\n")
+               cat ("\nRho (Y = 2) :\n")
                for (g in 1L:model$G) {
                   cat("Group :", var.names$g.names[[g]], "\n")
                   Rhomat <- sapply(1L:model$M, function(m)
